# busbar-core

Core framework for busbar, providing essential utilities and functionalities for the Muselab ecosystem.

## Installation

You can install `busbar-core` using Poetry:

```bash
poetry add busbar-core
```

Or install directly from the repository:

```bash
pip install git+https://github.com/composable-delivery/busbar/busbar-core.git
```
